@@ -102,7 +102,7 @@ sub execute
 #  }# end if()
   
   eval {
-    $s->{handler}->run( $s, @args );
+    $s->run_handler( $s->{handler}, @args );
     $s->response->Flush;
   };
   if( $@ )
@@ -128,6 +128,16 @@ sub execute
 }# end execute()
 
 
+#==============================================================================
+sub run_handler
+{
+  my ($s, $handler, @args) = @_;
+  $handler->before_run( $s, @args );
+  $handler->run( $s, @args );
+  $handler->after_run( $s, @args );
+}# end run_handler()
+
+
 #==============================================================================
 sub _resolve_request_handler { resolve_request_handler(@_) };
 sub resolve_request_handler
